###Analiza SNP##
install.packages("SNPassoc", dependencies = TRUE)
library(SNPassoc)
library(readxl)

###wczytaj plik baza_IL1.xlsx, nazij wczytana tabele baza

#płeć - k - kobieta, m - mężczyzna
#wiek - wiek podany w latach
#BMI - Body Mass Index
#casco - 0 dla BMI>25, 1 dla BMI<=25
#tłuszcz[%] - procentowa zawartość tłuszczu w organiźmie
#PPARA_rs1800206 - SNP znajdujący się w obrębie genu PPARA : Peroxisome Proliferator Activated Receptor Alpha : 
#gen PPARA w NCBI - https://www.ncbi.nlm.nih.gov/gene/5465
#PPARD (rs1801282,rs1053049,rs2267668) - SNP znajdujące się w obrębie genu PPARD : Peroxisome Proliferator Activated Receptor Delta
#gen PPARD w NCBI - https://www.ncbi.nlm.nih.gov/gene/5467

#wczytaj kolumny zawierające SNP jako ramkę danych
myData<-setupSNP(data=baza,colSNPs=6:9,sep="")

#sprawdź nazwy nagłówków (nazwy SNP)
labels(myData)

#sprawdź zgodność alleli z rozkładem HW w grupach wyznaczonych przez wartość BMI
res<- tableHWE(myData,strata=myData$casco)
res
#wczytaj pojedynczy SNP
mySNP<-snp(baza$PPARD_rs1801282,sep="")
summary(mySNP)

#zobrazuj rozkład genotypów
plot(mySNP,label="PPARD_rs1801282",col="darkgreen")



#sprawdź czy istnieje zależność między BMI i genotypem PPARD_rs2267668
#zmienna casco przyjmuje wartość 1 dla BMI <= 25, 0 dla BMI > 25
association(casco~snp(PPARD_rs2267668,sep=""), data=baza)

#OR - odds ratio, iloraz szans - stosunek szans wystąpienia zdarzenia w jednej grupie 
# do szansy wystąpienia w drugiej grupie


#zadanie 1#
#przeprowadź analogiczną analizę wpływu pozostałych SNP na BMI
# dla ktrych modeli genetycznych taki wplyw istnieje, zinterpretuj wyniki


#sprawdz czy istnieje interakcja miedzy genami PPARD oraz PPARA w wybranych rs, dodaj drugi SNP jako kolejny czynnik uzywajac znaku *factor(dominant/recessive/codominant(snp(_____,sep="")))

## znajdz istotne wplywy SNP na uraz sciegna z bazy TI2, zinterpretuj wyniki
 
# analiza haplotypw
#wczytaj krate haplotypy
# dane sa rekodowane 0 - heterozygota dominujaca, 1 - heterozygota, 2 - homozygota recesywna

library(haplo.stats)
gen1<-geno1to2(baza1) # rekoduje zmienne z 1 na dwie kolumny (0,1,2) -> (1/1, 1/2, 2/2)
casco<-baza$casco # wczytuje ta sama zmienna grupujaca

haplo.group(casco, gen1) # sprawdzam frekwencje poszczeglnych haplotypw

haplo.score(casco,gen1,trait.type = "binomial", haplo.effect = "recessive")
haplo.score(casco,gen1,trait.type = "binomial", haplo.effect = "dominant")
haplo.score(casco,gen1,trait.type = "binomial", haplo.effect = "additive")

#zobacz : https://www.medcalc.org/calc/odds_ratio.php

## GWAS ###
## Tworzymy dane genetyczne.
library(statgenGWAS)

geno <- matrix(sample(x = c(0, 1, 2), size = 15, replace = TRUE), nrow = 3)
dimnames(geno) <- list(paste0("G", 1:3), paste0("M", 1:5))

## Tworzymy mape.
map <- data.frame(chr = c(1, 1, 2, 2, 2), pos = 1:5,
                  row.names = paste0("M", 1:5))

## Tworzymy dane o fenotypie.
pheno <- data.frame(paste0("G", 1:3),
                    matrix(rnorm(n = 12, mean = 50, sd = 5), nrow = 3),
                    stringsAsFactors = FALSE)
dimnames(pheno) = list(paste0("G", 1:3), c("genotype", paste0("T", 1:4)))

## scalamy wszystkie dane w obiekt typu gData.
gData <- createGData(geno = geno, map = map, pheno = pheno)
summary(gData)
GWASDrops <- runSingleTraitGwas(gData = gData)



data(dropsMarkers)
data(dropsMap)
data(dropsPheno)

## Dodaj genotypy jako nazwy wierszy dropsMarkers i kolumne drop Ind.
rownames(dropsMarkers) <- dropsMarkers[["Ind"]]
dropsMarkers <- dropsMarkers[colnames(dropsMarkers) != "Ind"]

## Dodaj genotypy jako nazwy wierszy dropsMap.
rownames(dropsMap) <- dropsMap[["SNP.names"]]

## Zmien nazwy kolumn Chomosome i Position.
colnames(dropsMap)[match(c("Chromosome", "Position"), 
                         colnames(dropsMap))] <- c("chr", "pos")

## Konwersja danych fenotypowych na liste.
dropsPhenoList <- split(x = dropsPheno, f = dropsPheno[["Experiment"]])

## Zmien nazwe "Variety_ID" na "genotype" i wybierz odpowiednie kolumny.
dropsPhenoList <- lapply(X = dropsPhenoList, FUN = function(trial) {
  colnames(trial)[colnames(trial) == "Variety_ID"] <- "genotype"
  trial <- trial[c("genotype", "grain.yield", "grain.number", "seed.size",
                   "anthesis", "silking", "plant.height", "tassel.height",
                   "ear.height")]
  return(trial)
}) 


## Stwrz obiekt gData.
gDataDrops <- createGData(geno = dropsMarkers, map = dropsMap, pheno = dropsPhenoList)

## uruchom single trait GWAS dla 'grain.yield' dla eksperymentu "Mur13W".

GWASDrops <- runSingleTraitGwas(gData = gDataDrops,
                                trials = "Mur13W",
                                traits = "grain.yield")
# manhattan plot
plot(GWASDrops)
# qq plot
plot(GWASDrops, 
     plotType = "qq",
     title = "QQ plot for Mur13W")
summary(GWASDrops)

